@@ -1,5 +1,6 @@
 from .interval import Interval, I
 from .dists import *
-from .pbox import Pbox, env
+from .pbox import Pbox
 from .logic import *
-from .copula import *
+# from .copula import __all__
+from .core import *
\ No newline at end of file
